==> tencentcloud-sdk-java-3.1.57-sources.jar: com/tencentcloudapi/gse/v20191112/models/DescribeGameServerSessionPlacementResponse.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.gse.v20191112.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class DescribeGameServerSessionPlacementResponse extends AbstractModel{

    /**
    * 游戏服务器会话放置
    */
    @SerializedName("GameServerSessionPlacement")
    @Expose
    private GameServerSessionPlacement GameServerSessionPlacement;

    /**
    * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
    */
    @SerializedName("RequestId")
    @Expose
    private String RequestId;

    /**
     * Get 游戏服务器会话放置 
     * @return GameServerSessionPlacement 游戏服务器会话放置
     */
    public GameServerSessionPlacement getGameServerSessionPlacement() {
        return this.GameServerSessionPlacement;
    }

    /**
     * Set 游戏服务器会话放置
     * @param GameServerSessionPlacement 游戏服务器会话放置
     */
    public void setGameServerSessionPlacement(GameServerSessionPlacement GameServerSessionPlacement) {
        this.GameServerSessionPlacement = GameServerSessionPlacement;
    }

    /**
     * Get 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。 
     * @return RequestId 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     */
    public String getRequestId() {
        return this.RequestId;
    }

    /**
     * Set 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     * @param RequestId 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     */
    public void setRequestId(String RequestId) {
        this.RequestId = RequestId;
    }

    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamObj(map, prefix + "GameServerSessionPlacement.", this.GameServerSessionPlacement);
        this.setParamSimple(map, prefix + "RequestId", this.RequestId);

    }
}

==> tencentcloud-sdk-java-3.1.757-sources.jar: com/tencentcloudapi/gse/v20191112/models/DescribeGameServerSessionPlacementResponse.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.gse.v20191112.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class DescribeGameServerSessionPlacementResponse extends AbstractModel{

    /**
    * 游戏服务器会话放置
    */
    @SerializedName("GameServerSessionPlacement")
    @Expose
    private GameServerSessionPlacement GameServerSessionPlacement;

    /**
    * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
    */
    @SerializedName("RequestId")
    @Expose
    private String RequestId;

    /**
     * Get 游戏服务器会话放置 
     * @return GameServerSessionPlacement 游戏服务器会话放置
     */
    public GameServerSessionPlacement getGameServerSessionPlacement() {
        return this.GameServerSessionPlacement;
    }

    /**
     * Set 游戏服务器会话放置
     * @param GameServerSessionPlacement 游戏服务器会话放置
     */
    public void setGameServerSessionPlacement(GameServerSessionPlacement GameServerSessionPlacement) {
        this.GameServerSessionPlacement = GameServerSessionPlacement;
    }

    /**
     * Get 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。 
     * @return RequestId 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     */
    public String getRequestId() {
        return this.RequestId;
    }

    /**
     * Set 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     * @param RequestId 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     */
    public void setRequestId(String RequestId) {
        this.RequestId = RequestId;
    }

    public DescribeGameServerSessionPlacementResponse() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public DescribeGameServerSessionPlacementResponse(DescribeGameServerSessionPlacementResponse source) {
        if (source.GameServerSessionPlacement != null) {
            this.GameServerSessionPlacement = new GameServerSessionPlacement(source.GameServerSessionPlacement);
        }
        if (source.RequestId != null) {
            this.RequestId = new String(source.RequestId);
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamObj(map, prefix + "GameServerSessionPlacement.", this.GameServerSessionPlacement);
        this.setParamSimple(map, prefix + "RequestId", this.RequestId);

    }
}
